@@ -1100,7 +1100,7 @@ GTKDeviceDriver(DevDesc *odd, char *display, double width,
 
     /* font loading */
     ps = pointsize;
-    if(ps < 6 || ps > 24) ps = 12;
+    if(ISNAN(ps) || ps < 6 || ps > 24) ps = 12;
     ps = 2 * (ps / 2);
     gtkd->fontface = -1;
     gtkd->fontsize = -1;
@@ -1229,7 +1229,7 @@ GTKDeviceFromWidget(DevDesc *odd, char *widget, double width, double height, dou
 
     /* font loading */
     ps = pointsize;
-    if(ps < 6 || ps > 24) ps = 12;
+    if(ISNAN(ps) || ps < 6 || ps > 24) ps = 12;
     ps = 2 * (ps / 2);
     gtkd->fontface = -1;
     gtkd->fontsize = -1;
